function [tmp_subdir]=CreateTMPdir(tmp_dir,mfile);
% CREATETMPDIR creates unique tmp directory
% [tmp_subdir]=CreateTMPdir(tmp_dir,mfile);
%
% Creates a unique sub(working) directory in the tmp_dir 
%  name of subdirectory will consist of:
%   "mfile"-"date"-"time"-"unique number" 
% Example CreateTMPdir-2000814-120000-1 
% Will always end with fileseparator (filesep)
% Will abort after three failed attempts

% ---------------------------------
% Copyright (c) 2003 Serge Dumoulin
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License version 2
% as published by the Free Software Foundation.
% ---------------------------------

if(nargin < 1 | isempty(tmp_dir)),
   tmp_dir=tempdir;
end;
if(nargin < 2 | isempty(mfile)),
   mfile=mfilename;
end;

rand('state',sum(100*clock));

if(exist(tmp_dir,'dir')~=7),
   disp(sprintf('[%s]:%s does not exist -> changing to %s',mfilename,tmp_dir,tempdir));   
   tmp_dir=tempdir;
   if(exist(tmp_dir,'dir')~=7),
      disp(sprintf('[%s]:%s does not exist - exit program',mfilename,tmp_dir));
      return;
   end;
end;

status=0;
for attempt=1:3,
  % create sub(working) directory:
  t             = fix(clock);
  mydir         = sprintf('%s-%d%2d%2d-%2d%2d%2d',mfile,...
                          t(1),t(2),t(3),t(4),t(5),t(6));
  spaces        = findstr(mydir,' ');
  mydir(spaces) = '0';
  
  status=mkdir(tmp_dir,mydir);
  if status~=1,
    disp(sprintf('[%s]:WARNING: error reported by mkdir (status=%.1f\nattempt %d)',...
                 mfilename,status,attempt));
    pause(round(rand*30)); % wait (max 30 secs) and try again
  else,
    break;
  end;
end;

if tmp_dir(end)==filesep,
   tmp_subdir=[tmp_dir mydir filesep];
else,
   tmp_subdir=[tmp_dir filesep mydir filesep];
end;
